@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: yesod-core
 version: 1.4.19
-id: yesod-core-1.4.19-76e562217b8c2dec9e581394dccca7d9
-key: yesod_9GnH5Dtt3njI71AJEi3O22
+id: yesod-core-1.4.19-b6ec8d224ea1c49c36126eee73b10ab6
+key: yesod_76zPmIEOwOE5jBTSzRfVmf
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -33,55 +33,55 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.19
 library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-core-1.4.19
 data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-core-1.4.19
-hs-libraries: HSyesod-core-1.4.19-9GnH5Dtt3njI71AJEi3O22
+hs-libraries: HSyesod-core-1.4.19-76zPmIEOwOE5jBTSzRfVmf
 depends:
-    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
+    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
     auto-update-0.1.3-4edf36ce78b71bfaad1ce3737442c65f
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
-    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
-    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
+    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
+    blaze-html-0.8.1.1-1d54daeba5477a1aa0462b832a558865
+    blaze-markup-0.7.0.3-fed4a147945def017f9ea9594b30666a
     byteable-0.1.1-b91304cc70dc43f4dc186dc9711b3917
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.6-c798f9d7ea7ba5a96fa5679d606aad7f
+    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
     cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
     clientsession-0.9.1.1-763bfd866302839ae7dcaa53517a3160
     conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
-    conduit-extra-1.1.11-a2feb7bf273f01f86e07dfa0c39c1b6a
+    conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    cookie-0.4.1.6-8a746b417cee9e54ae77a0b2d5e8515e
+    cookie-0.4.1.6-97fa5cf54d4ed1e2644dbcebe7255b51
     data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
-    fast-logger-2.4.1-72875ca91290e61690089a3e7f5d8466
-    http-types-0.9-181a315082d46c3ed5dffe75933f2447
+    fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
+    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
     lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
     monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
-    monad-logger-0.3.18-7704b739a8ba950a4b62906c3ab56228
+    monad-logger-0.3.18-0974645d267a817a7b3484945a31ce66
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     mwc-random-0.13.4.0-5fa3ad33ef5e7f15e9e572967b6dc242
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
-    path-pieces-0.2.1-c4c6ea4593a7da7123f92fac6c85ebd3
+    parsec-3.1.9-3365ddffd9ca11d2f0b377e002b54baf
+    path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
     primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
     resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
     safe-0.3.9-b613242f536083d5bb04920ede356aea
-    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
-    shakespeare-2.0.7-39cc4f42107716d9e8a539beb0a84dc6
+    semigroups-0.18.1-30b269dfd15f1b13a72c07aebe8ef1de
+    shakespeare-2.0.8-88acbcac23cb55d5f3c82ebba9b11159
     template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
     unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
-    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
+    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    wai-3.2.0-e103f0650175c07d97df46c35b6789e8
-    wai-extra-3.0.14.1-0c42224b2d6876be23597f0341613f03
-    wai-logger-2.2.4.1-174bc5cb20d0c648b67c086b95df789c
-    warp-3.2.3-65ec311029bca8d40c69f107435d220d
+    wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
+    wai-extra-3.0.15-954ac840c460f6e3c2fb191ca01c5fce
+    wai-logger-2.2.4.1-9478a6051df96b8d5b3214f7fcca2185
+    warp-3.2.3-6de819de378ae4c57281b63b66004254
     word8-0.1.2-9a296ac80618be494d93f29b398e749d
 haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
 haddock-html: /usr/share/doc/haskell-yesod-core/html
